@@ -20,12 +20,12 @@ shortToLongStatus = {
     "w3c/PR": "W3C Proposed Recommendation",
     "w3c/REC": "W3C Recommendation",
     "w3c/PER": "W3C Proposed Edited Recommendation",
-    "w3c/WG-NOTE": "W3C Working Group Note",
-    "w3c/IG-NOTE": "W3C Interest Group Note",
-    "w3c/NOTE": "W3C Note",
+    "w3c/WG-NOTE": "W3C Group Note",
+    "w3c/IG-NOTE": "W3C Group Note",
+    "w3c/NOTE": "W3C Group Note",
     "w3c/NOTE-ED": "Editor's Draft",
-    "w3c/NOTE-WD": "W3C Working Draft",
-    "w3c/NOTE-FPWD": "W3C First Public Working Draft",
+    "w3c/NOTE-WD": "W3C Group Draft Note",
+    "w3c/NOTE-FPWD": "W3C Group Draft Note",
     "w3c/MO": "W3C Member-only Draft",
     "w3c/UD": "Unofficial Proposal Draft",
     "w3c/CG-DRAFT": "Draft Community Group Report",
@@ -191,16 +191,17 @@ megaGroups = {
     "w3c": frozenset(
         [
             "act-framework",
+            "act-rules-format",
             "audiowg",
             "browser-testing-tools",
             "csswg",
             "dap",
             "fxtf",
-            "fxtf-csswg",
             "geolocation",
             "gpuwg",
             "houdini",
             "html",
+            "httpslocal",
             "i18n",
             "immersivewebcg",
             "immersivewebwg",
@@ -220,6 +221,7 @@ megaGroups = {
             "uievents",
             "wasm",
             "web-bluetooth-cg",
+            "web-payments",
             "webapps",
             "webappsec",
             "webauthn",
@@ -227,7 +229,6 @@ megaGroups = {
             "webfontswg",
             "webml",
             "webmlwg",
-            "web-payments",
             "webperf",
             "webplatform",
             "webrtc",
