@@ -12,7 +12,7 @@ def update(path, dryRun=False):
             "https://raw.githubusercontent.com/tabatkins/bikeshed/main/bikeshed/spec-data/readonly/link-defaults.infotree"
         ).text
     except Exception as e:
-        die("Couldn't download link defaults data.\n{0}", e)
+        die(f"Couldn't download link defaults data.\n{e}")
         return
 
     if not dryRun:
@@ -20,6 +20,6 @@ def update(path, dryRun=False):
             with open(os.path.join(path, "link-defaults.infotree"), "w", encoding="utf-8") as f:
                 f.write(data)
         except Exception as e:
-            die("Couldn't save link-defaults database to disk.\n{0}", e)
+            die(f"Couldn't save link-defaults database to disk.\n{e}")
             return
     say("Success!")
